==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoArcCircleArea/ts/InfoArcCircleArea_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoArcCircleArea</name>
    <message>
        <location filename="../InfoArcCircleArea.js" line="+70"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+233"/>
        <location line="+21"/>
        <location line="+24"/>
        <location line="+21"/>
        <location line="+22"/>
        <location line="+22"/>
        <source>Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+66"/>
        <source>Circumference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+24"/>
        <source>Ellipse arc area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-23"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <source>arc length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-88"/>
        <location line="+67"/>
        <source>chord:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-52"/>
        <source>Distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>distance:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+65"/>
        <source>radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-9"/>
        <source>Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Circle area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-245"/>
        <source>Choose arc, circle, ellipse or elliptical arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+246"/>
        <location line="+67"/>
        <source>circumference:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Ellipse area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+22"/>
        <source>Arc area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+17"/>
        <source>Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Calculate Area of Sector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Calculate Area of Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Add:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add entities to drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-96"/>
        <location line="+67"/>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Chord</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Add lengths/circumference to drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-68"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <location filename="../InfoArcCircleArea.ui" line="+3"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleAreaInit.js" line="+2"/>
        <source>Arc/Circle/Ellipse Area</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoArcCircleArea/ts/InfoArcCircleArea_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoArcCircleArea</name>
    <message>
        <location filename="../InfoArcCircleArea.js" line="+73"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+233"/>
        <location line="+21"/>
        <location line="+24"/>
        <location line="+21"/>
        <location line="+22"/>
        <location line="+22"/>
        <source>Area</source>
        <translation>Pole powierzchni</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+66"/>
        <source>Circumference</source>
        <translation>Obwód</translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+24"/>
        <source>Ellipse arc area:</source>
        <translation>Pole powierzchni odcinka elipsy:</translation>
    </message>
    <message>
        <location line="-23"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <source>arc length:</source>
        <translation>długość łuku:</translation>
    </message>
    <message>
        <location line="-88"/>
        <location line="+67"/>
        <source>chord:</source>
        <translation>cięciwa:</translation>
    </message>
    <message>
        <location line="-52"/>
        <source>Distance</source>
        <translation>Odległość</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>distance:</source>
        <translation>odległość:</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>radius:</source>
        <translation>promień:</translation>
    </message>
    <message>
        <location line="-9"/>
        <source>Radius</source>
        <translation>Promień</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Circle area:</source>
        <translation>Pole powierzchni koła:</translation>
    </message>
    <message>
        <location line="-245"/>
        <source>Choose arc, circle, ellipse or elliptical arc</source>
        <translation>Proszę wskazać łuk, okrąg, elipsę lub łuk elipsy</translation>
    </message>
    <message>
        <location line="+246"/>
        <location line="+67"/>
        <source>circumference:</source>
        <translation>obwód:</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Ellipse area:</source>
        <translation>Pole powierzchni elipsy:</translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+22"/>
        <source>Arc area:</source>
        <translation>Pole powierzchni odcinka koła:</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+17"/>
        <source>Mode:</source>
        <translation>Tryb:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Calculate Area of Sector</source>
        <translation>Oblicz pole powierzchni wycinka</translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Calculate Area of Segment</source>
        <translation>Oblicz pole powierzchni odcinka</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Add:</source>
        <translation>Dodanie:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add entities to drawing</source>
        <translation>Dodaje obiekty do rysunku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Obiekt</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-96"/>
        <location line="+67"/>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Chord</source>
        <translation>Cięciwa</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Add lengths/circumference to drawing</source>
        <translation>Dodaje długość/obwód do rysunku</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-68"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <location filename="../InfoArcCircleArea.ui" line="+3"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleAreaInit.js" line="+2"/>
        <source>Arc/Circle/Ellipse Area</source>
        <translation>Pole powierzchni łuku/koła/elipsy</translation>
    </message>
</context>
</TS>
